@@ -11,7 +11,7 @@ use Astro::Coord::ECI::Utils qw{ __default_station PIOVER2 SECSPERDAY };
 use Exporter ();
 use POSIX qw{ floor };
 
-our $VERSION = '0.073';
+our $VERSION = '0.074';
 
 our @EXPORT_OK = qw{
     almanac almanac_hash
@@ -57,16 +57,17 @@ sub almanac {
 }
 
 sub almanac_hash {
+    my ( $self, $station, $start, $end ) = __default_station( @_ );
     return map {
-	body => $_[0],
-	station => $_[1],
+	body => $self,
+	station => $station,
 	time => $_->[0],
 	almanac => {
 	    event => $_->[1],
 	    detail => $_->[2],
 	    description => $_->[3],
 	}
-    }, almanac(@_);
+    }, $self->almanac( $station, $start, $end );
 }
 
 sub next_quarter {
